@@ -13,7 +13,7 @@ use crate::engine::objects::resolvers::visitors::{
     visit_node_update_input, visit_rel_create_input, visit_rel_delete_input, visit_rel_query_input,
     visit_rel_update_input,
 };
-use crate::engine::objects::{Node, Rel};
+use crate::engine::objects::{Node, Options, Rel};
 use crate::engine::schema::Info;
 use crate::engine::value::Value;
 use crate::juniper::BoxFuture;
@@ -243,13 +243,16 @@ pub struct EventHandlerBag<RequestCtx: RequestContext> {
     after_request_handlers: Vec<AfterRequestFunc<RequestCtx>>,
     before_create_handlers: HashMap<String, Vec<BeforeMutationEventFunc<RequestCtx>>>,
     after_node_create_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
+    after_subgraph_create_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
     after_rel_create_handlers: HashMap<String, Vec<AfterRelEventFunc<RequestCtx>>>,
     before_read_handlers: HashMap<String, Vec<BeforeQueryEventFunc<RequestCtx>>>,
     after_node_read_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
     after_rel_read_handlers: HashMap<String, Vec<AfterRelEventFunc<RequestCtx>>>,
     before_update_handlers: HashMap<String, Vec<BeforeMutationEventFunc<RequestCtx>>>,
     after_node_update_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
+    after_node_subgraph_update_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
     after_rel_update_handlers: HashMap<String, Vec<AfterRelEventFunc<RequestCtx>>>,
+    after_rel_subgraph_update_handlers: HashMap<String, Vec<AfterRelEventFunc<RequestCtx>>>,
     before_delete_handlers: HashMap<String, Vec<BeforeMutationEventFunc<RequestCtx>>>,
     after_node_delete_handlers: HashMap<String, Vec<AfterNodeEventFunc<RequestCtx>>>,
     after_rel_delete_handlers: HashMap<String, Vec<AfterRelEventFunc<RequestCtx>>>,
@@ -272,13 +275,16 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
             after_request_handlers: vec![],
             before_create_handlers: HashMap::new(),
             after_node_create_handlers: HashMap::new(),
+            after_subgraph_create_handlers: HashMap::new(),
             after_rel_create_handlers: HashMap::new(),
             before_read_handlers: HashMap::new(),
             after_node_read_handlers: HashMap::new(),
             after_rel_read_handlers: HashMap::new(),
             before_update_handlers: HashMap::new(),
             after_node_update_handlers: HashMap::new(),
+            after_node_subgraph_update_handlers: HashMap::new(),
             after_rel_update_handlers: HashMap::new(),
+            after_rel_subgraph_update_handlers: HashMap::new(),
             before_delete_handlers: HashMap::new(),
             after_node_delete_handlers: HashMap::new(),
             after_rel_delete_handlers: HashMap::new(),
@@ -436,7 +442,11 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         }
     }
 
-    /// Registers an event handler `f` to be called after a node of type `type_name` is created.
+    /// Registers an event handler `f` to be called after a node of type `type_name` is created. Note that this handler
+    /// is called immediately after the creation of the node. If the node creation input includes relationships and
+    /// destination nodes to be created at the same time, they will not yet have been created at the time this handler
+    /// is called. See the `register_after_subgraph_create` function handlers that are called after the entire
+    /// sub-graph is created.
     ///
     /// # Examples
     ///
@@ -471,6 +481,44 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         }
     }
 
+    /// Registers an event handler `f` to be called after a node of type `type_name` is created. This handler is called
+    /// after all additional destination nodes and relationships bundled into the same creation operation input have
+    /// also been created. Use `register_after_node_create` for an event to be called after the node itself is created
+    /// but before the remainder of the nested sub-graph.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use warpgrapher::engine::events::{EventHandlerBag, EventFacade};
+    /// # use warpgrapher::Error;
+    /// # use warpgrapher::engine::value::Value;
+    /// # use warpgrapher::engine::objects::Node;
+    /// # use warpgrapher::juniper::BoxFuture;
+    ///
+    /// fn after_user_create(nodes: Vec<Node<()>>, ef: EventFacade<()>) -> BoxFuture<Result<Vec<Node<()>>, Error>> {
+    ///    Box::pin(async move {
+    ///         // Normally work would be done here, resulting in some new value.
+    ///         Ok(nodes)
+    ///    })
+    /// }
+    ///
+    /// let mut handlers = EventHandlerBag::<()>::new();
+    /// handlers.register_after_subgraph_create(vec!["User".to_string()], after_user_create);
+    /// ```
+    pub fn register_after_subgraph_create(
+        &mut self,
+        names: Vec<String>,
+        f: AfterNodeEventFunc<RequestCtx>,
+    ) {
+        for name in names {
+            if let Some(handlers) = self.after_subgraph_create_handlers.get_mut(&name) {
+                handlers.push(f);
+            } else {
+                self.after_subgraph_create_handlers.insert(name, vec![f]);
+            }
+        }
+    }
+
     /// Registers an event handler `f` to be called after a rel is created.
     ///
     /// # Examples
@@ -716,7 +764,11 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         }
     }
 
-    /// Registers an event handler `f` to be called after a node of type `type_name` is updated.
+    /// Registers an event handler `f` to be called after a node of type `type_name` is updated. Note that this handler
+    /// is called immediately after the update of the node. If the node update input includes relationships and
+    /// destination nodes to be updated at the same time, they will not yet have been updated at the time this handler
+    /// is called. See the `register_after_node_subgraph_update` function handlers that are called after the entire
+    /// sub-graph is udpated.
     ///
     /// # Examples
     ///
@@ -751,7 +803,50 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         }
     }
 
-    /// Registers an event handler `f` to be called after a rel is updated.
+    /// Registers an event handler `f` to be called after a node of type `type_name` is updated. This handler is called
+    /// after all additional destination nodes and relationships bundled into the same update operation input have
+    /// also been updated. Use `register_after_node_update` for an event to be called after the node itself
+    /// is updated but before the remainder of the nested sub-graph.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use warpgrapher::engine::events::{EventHandlerBag, EventFacade};
+    /// # use warpgrapher::Error;
+    /// # use warpgrapher::engine::value::Value;
+    /// # use warpgrapher::engine::objects::Node;
+    /// # use warpgrapher::juniper::BoxFuture;
+    ///
+    /// fn after_user_update(nodes: Vec<Node<()>>, ef: EventFacade<()>) -> BoxFuture<Result<Vec<Node<()>>, Error>> {
+    ///    Box::pin(async move {
+    ///        // Normally work would be done here, resulting in some new value.
+    ///        Ok(nodes)
+    ///    })
+    /// }
+    ///
+    /// let mut handlers = EventHandlerBag::<()>::new();
+    /// handlers.register_after_node_subgraph_update(vec!["User".to_string()], after_user_update);
+    /// ```
+    pub fn register_after_node_subgraph_update(
+        &mut self,
+        type_names: Vec<String>,
+        f: AfterNodeEventFunc<RequestCtx>,
+    ) {
+        for type_name in type_names {
+            if let Some(handlers) = self.after_node_subgraph_update_handlers.get_mut(&type_name) {
+                handlers.push(f);
+            } else {
+                self.after_node_subgraph_update_handlers
+                    .insert(type_name, vec![f]);
+            }
+        }
+    }
+
+    /// Registers an event handler `f` to be called after a rel is updated.  Note that this handler
+    /// is called immediately after the update of the relationship. If the node update input includes source,
+    /// destination, or other relationship updates, they will not yet have been updated at the time this handler
+    /// is called. See the `register_after_rel_subgraph_update` function handlers that are called after the entire
+    /// sub-graph is updated.
     ///
     /// # Examples
     ///
@@ -788,6 +883,45 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         }
     }
 
+    /// Registers an event handler `f` to be called after a relationship is updated. This handler is called
+    /// after all additional source nodes, destination nodes, and relationships bundled into the same update
+    /// operation input have also been updated. Use `register_after_rel_update` for an event to be
+    /// called after the node itself is updated but before the remainder of the nested sub-graph.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use warpgrapher::engine::events::{EventHandlerBag, EventFacade};
+    /// # use warpgrapher::Error;
+    /// # use warpgrapher::engine::value::Value;
+    /// # use warpgrapher::engine::objects::Node;
+    /// # use warpgrapher::juniper::BoxFuture;
+    ///
+    /// fn after_user_update(nodes: Vec<Node<()>>, ef: EventFacade<()>) -> BoxFuture<Result<Vec<Node<()>>, Error>> {
+    ///    Box::pin(async move {
+    ///        // Normally work would be done here, resulting in some new value.
+    ///        Ok(nodes)
+    ///    })
+    /// }
+    ///
+    /// let mut handlers = EventHandlerBag::<()>::new();
+    /// handlers.register_after_node_subgraph_update(vec!["User".to_string()], after_user_update);
+    /// ```
+    pub fn register_after_rel_subgraph_update(
+        &mut self,
+        rel_names: Vec<String>,
+        f: AfterRelEventFunc<RequestCtx>,
+    ) {
+        for rel_name in rel_names {
+            if let Some(handlers) = self.after_rel_subgraph_update_handlers.get_mut(&rel_name) {
+                handlers.push(f);
+            } else {
+                self.after_rel_subgraph_update_handlers
+                    .insert(rel_name, vec![f]);
+            }
+        }
+    }
+
     /// Registers an event handler `f` to be called before a node of type `type_name` is deleted.
     ///
     /// # Examples
@@ -962,6 +1096,13 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         self.after_node_create_handlers.get(type_name)
     }
 
+    pub(crate) fn after_subgraph_create(
+        &self,
+        type_name: &str,
+    ) -> Option<&Vec<AfterNodeEventFunc<RequestCtx>>> {
+        self.after_subgraph_create_handlers.get(type_name)
+    }
+
     pub(crate) fn after_rel_create(
         &self,
         rel_name: &str,
@@ -1018,6 +1159,13 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         self.after_node_update_handlers.get(type_name)
     }
 
+    pub(crate) fn after_node_subgraph_update(
+        &self,
+        type_name: &str,
+    ) -> Option<&Vec<AfterNodeEventFunc<RequestCtx>>> {
+        self.after_node_subgraph_update_handlers.get(type_name)
+    }
+
     pub(crate) fn after_rel_update(
         &self,
         rel_name: &str,
@@ -1025,6 +1173,13 @@ impl<RequestCtx: RequestContext> EventHandlerBag<RequestCtx> {
         self.after_rel_update_handlers.get(rel_name)
     }
 
+    pub(crate) fn after_rel_subgraph_update(
+        &self,
+        rel_name: &str,
+    ) -> Option<&Vec<AfterRelEventFunc<RequestCtx>>> {
+        self.after_rel_subgraph_update_handlers.get(rel_name)
+    }
+
     pub(crate) fn before_node_delete(
         &self,
         type_name: &str,
@@ -1062,13 +1217,16 @@ impl<RequestCtx: RequestContext> Default for EventHandlerBag<RequestCtx> {
             after_request_handlers: vec![],
             before_create_handlers: HashMap::new(),
             after_node_create_handlers: HashMap::new(),
+            after_subgraph_create_handlers: HashMap::new(),
             after_rel_create_handlers: HashMap::new(),
             before_read_handlers: HashMap::new(),
             after_node_read_handlers: HashMap::new(),
             after_rel_read_handlers: HashMap::new(),
             before_update_handlers: HashMap::new(),
             after_node_update_handlers: HashMap::new(),
+            after_node_subgraph_update_handlers: HashMap::new(),
             after_rel_update_handlers: HashMap::new(),
+            after_rel_subgraph_update_handlers: HashMap::new(),
             before_delete_handlers: HashMap::new(),
             after_node_delete_handlers: HashMap::new(),
             after_rel_delete_handlers: HashMap::new(),
@@ -1177,20 +1335,22 @@ where
     /// # Arguments
     ///
     /// * `type_name` - String reference represing name of node type (ex: "User").
-    /// * `input` - Optional `Value` describing which node to match. Same input structure passed to a READ crud operation (`<Type>QueryInput`).
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `input` - Optional `Value` describing which node to match. Same input structure
+    ///   passed to a READ crud operation (`<Type>QueryInput`).
+    /// * `options` - Optional structure with arguments that affect the behavior of the query
     ///
     /// # Examples
     ///
     /// ```rust, no_run
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
     /// fn before_user_read(value: Value, mut ef: EventFacade<()>) -> BoxFuture<Result<Value, Error>> {
     ///     Box::pin(async move {
-    ///         let nodes_to_be_read = ef.read_nodes("User", value.clone(), None).await?;
+    ///         let nodes_to_be_read = ef.read_nodes("User", value.clone(), Options::default()).await?;
     ///         // modify value before passing it forward ...
     ///         Ok(value)
     ///     })
@@ -1200,7 +1360,7 @@ where
         &mut self,
         type_name: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Vec<Node<RequestCtx>>, Error> {
         let mut info = self.info.clone();
         info.name = "Query".to_string();
@@ -1215,8 +1375,8 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?),
+            options.clone(),
             &Info::new(format!("{}QueryInput", type_name), info.type_defs()),
-            partition_key_opt,
             &mut sg,
             self.transaction,
         )
@@ -1224,7 +1384,7 @@ where
 
         let results = self
             .transaction
-            .read_nodes(&node_var, query_fragment, partition_key_opt, &info)
+            .read_nodes(&node_var, query_fragment, options, &info)
             .await;
         results
     }
@@ -1237,19 +1397,20 @@ where
     ///
     /// * `type_name` - String reference represing name of node type (ex: "User").
     /// * `input` - `Value` describing the node to create.
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Options affecting how a query is performed, such as sort ordering
     ///
     /// # Examples
     ///
     /// ```rust, no_run
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
     /// fn before_user_read(value: Value, mut ef: EventFacade<()>) -> BoxFuture<Result<Value, Error>> {
     ///     Box::pin(async move {
-    ///         let new_node = ef.create_node("Team", value.clone(), None).await?;
+    ///         let new_node = ef.create_node("Team", value.clone(), Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1258,7 +1419,7 @@ where
         &mut self,
         type_name: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Node<RequestCtx>, Error> {
         let mut sg = SuffixGenerator::new();
         let node_var =
@@ -1269,11 +1430,11 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(
                 format!("{}CreateMutationInput", type_name),
                 self.info.type_defs(),
             ),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
@@ -1290,7 +1451,7 @@ where
     ///
     /// * `type_name` - String reference represing name of node type (ex: "User").
     /// * `input` - `Value` describing the node to update.
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments describing how a query is performed, such as a sort order
     ///
     /// # Examples
     ///
@@ -1298,6 +1459,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1309,7 +1471,7 @@ where
     ///                 "MATCH": {"name": {"EQ": "alice"}},
     ///                 "SET": {"name": "eve"}
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1318,7 +1480,7 @@ where
         &mut self,
         type_name: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Vec<Node<RequestCtx>>, Error> {
         let mut sg = SuffixGenerator::new();
         let node_var =
@@ -1329,8 +1491,8 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(format!("{}UpdateInput", type_name), self.info.type_defs()),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
@@ -1347,7 +1509,7 @@ where
     ///
     /// * `type_name` - String reference represing name of node type (ex: "User").
     /// * `input` - `Value` describing the node to update.
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments affecting a query, such as a sort order
     ///
     /// # Examples
     ///
@@ -1355,6 +1517,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1365,7 +1528,7 @@ where
     ///             json!({
     ///                 "MATCH": {"name": {"EQ": "alice"}}
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1374,7 +1537,7 @@ where
         &mut self,
         type_name: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<i32, Error> {
         let mut sg = SuffixGenerator::new();
         let node_var =
@@ -1385,8 +1548,8 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(format!("{}DeleteInput", type_name), self.info.type_defs()),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
@@ -1404,7 +1567,7 @@ where
     /// * `src_node_label` - String reference represing name of node type (ex: "User").
     /// * `rel_label` - String reference representing the name of the relationship (ex: "teams").
     /// * `input` - `Value` describing the relationship query input.
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments affecting a query, such as a sort order
     ///
     /// # Examples
     ///
@@ -1412,7 +1575,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
-    /// # use warpgrapher::engine::objects::Rel;
+    /// # use warpgrapher::engine::objects::{Options, Rel};
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1424,7 +1587,7 @@ where
     ///             json!({
     ///                 "src": {"name": {"EQ": "alice"}}
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1434,7 +1597,7 @@ where
         src_node_label: &str,
         rel_label: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Vec<Rel<RequestCtx>>, Error> {
         let input_value_opt = Some(input.try_into().map_err(|_e| Error::TypeConversionFailed {
             src: "TryInto<Value>".to_string(),
@@ -1462,8 +1625,8 @@ where
             None,
             &rel_var,
             input_value_opt,
+            options.clone(),
             &info,
-            partition_key_opt,
             &mut sg,
             self.transaction,
         )
@@ -1471,7 +1634,7 @@ where
 
         let results = self
             .transaction
-            .read_rels(query_fragment, &rel_var, partition_key_opt)
+            .read_rels(query_fragment, &rel_var, options)
             .await?;
 
         Ok(results)
@@ -1486,7 +1649,7 @@ where
     /// * `src_node_label` - String reference represing name of node type (ex: "User").
     /// * `rel_label` - String reference representing the name of the relationship (ex: "teams")
     /// * `input` - `Value` describing the relationship creation input
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments affecting a query, such a sort order
     ///
     /// # Examples
     ///
@@ -1494,6 +1657,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1515,7 +1679,7 @@ where
     ///                     }
     ///                 }
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1525,7 +1689,7 @@ where
         src_node_label: &str,
         rel_label: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Vec<Rel<RequestCtx>>, Error> {
         let mut sg = SuffixGenerator::new();
         let src_var = NodeQueryVar::new(
@@ -1541,6 +1705,7 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(
                 format!(
                     "{}{}CreateInput",
@@ -1552,7 +1717,6 @@ where
                 ),
                 self.info.type_defs(),
             ),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
@@ -1571,7 +1735,7 @@ where
     /// * `src_node_label` - String reference represing name of node type (ex: "User").
     /// * `rel_label` - String reference representing the name of the relationship (ex: "teams")
     /// * `input` - `Value` describing the relationship update input
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments affecting a query, such as a sort order
     ///
     /// # Examples
     ///
@@ -1579,6 +1743,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1591,7 +1756,7 @@ where
     ///                 "MATCH": {"src": {"name": {"EQ": "alice"}}, "dst": {"name": {"EQ": "project_team_name"}}},
     ///                 "SET": {"sort_order": 2}
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///         Ok(value)
     ///     })
     /// }
@@ -1601,7 +1766,7 @@ where
         src_node_label: &str,
         rel_label: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<Vec<Rel<RequestCtx>>, Error> {
         let mut sg = SuffixGenerator::new();
         let rel_var = RelQueryVar::new(
@@ -1622,6 +1787,7 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(
                 format!(
                     "{}{}UpdateInput",
@@ -1633,7 +1799,6 @@ where
                 ),
                 self.info.type_defs(),
             ),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
@@ -1652,7 +1817,7 @@ where
     /// * `src_node_label` - String reference represing name of src node type type (ex: "User").
     /// * `rel_label` - String reference representing the name of the relationship (ex: "teams")
     /// * `input` - `Value` describing the relationship delete input
-    /// * `partition_key_opt` - Optional `Value` describing the partition key if the underlying database supports it.
+    /// * `options` - Optional arguments affecting a query, such as a sort order
     ///
     /// # Examples
     ///
@@ -1660,6 +1825,7 @@ where
     /// # use serde_json::json;
     /// # use warpgrapher::Error;
     /// # use warpgrapher::engine::events::EventFacade;
+    /// # use warpgrapher::engine::objects::Options;
     /// # use warpgrapher::engine::value::Value;
     /// # use warpgrapher::juniper::BoxFuture;
     ///
@@ -1672,7 +1838,7 @@ where
     ///                 "MATCH": {"src": {"Card": {"name": {"EQ": "alice"}}},
     ///                     "dst": {"Team": {"name": {"EQ": "project_team_name"}}}}
     ///             }),
-    ///             None).await?;
+    ///             Options::default()).await?;
     ///
     ///         Ok(value)
     ///     })
@@ -1683,7 +1849,7 @@ where
         src_node_label: &str,
         rel_label: &str,
         input: impl TryInto<Value>,
-        partition_key_opt: Option<&Value>,
+        options: Options,
     ) -> Result<i32, Error> {
         let mut sg = SuffixGenerator::new();
         let rel_var = RelQueryVar::new(
@@ -1704,6 +1870,7 @@ where
                 src: "".to_string(),
                 dst: "".to_string(),
             })?,
+            options,
             &Info::new(
                 format!(
                     "{}{}DeleteInput",
@@ -1715,7 +1882,6 @@ where
                 ),
                 self.info.type_defs(),
             ),
-            partition_key_opt,
             &mut sg,
             self.transaction,
             self.context(),
