@@ -117,8 +117,8 @@ async fn test_before_request_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await;
 
@@ -143,8 +143,8 @@ async fn test_after_request_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await;
 
@@ -169,8 +169,8 @@ async fn test_before_node_create_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -193,8 +193,8 @@ async fn test_before_node_read_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -204,7 +204,7 @@ async fn test_before_node_read_handler() {
     assert_eq!(p0.get("status").unwrap(), "PENDING");
 
     let projects = client
-        .read_node("Project", "id status", Some("1234"), None)
+        .read_node("Project", "id status", None, None)
         .await
         .unwrap();
 
@@ -226,8 +226,8 @@ async fn test_before_node_update_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -240,9 +240,9 @@ async fn test_before_node_update_handler() {
         .update_node(
             "Project",
             "__typename id name status",
-            Some("1234"),
             Some(&json!({"name": {"EQ": "MJOLNIR"}})),
             &json!({"status": "ACTIVE"}),
+            None,
         )
         .await
         .unwrap();
@@ -265,8 +265,8 @@ async fn test_before_node_delete_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -277,9 +277,9 @@ async fn test_before_node_delete_handler() {
     let pd = client
         .delete_node(
             "Project",
-            Some("1234"),
             Some(&json!({"name": {"EQ": "MJOLNIR"}})),
             None,
+            None,
         )
         .await
         .unwrap();
@@ -302,8 +302,32 @@ async fn test_after_node_create_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
+        )
+        .await
+        .unwrap();
+
+    assert!(p0.is_null());
+}
+
+#[cfg(feature = "cypher")]
+#[tokio::test]
+async fn test_after_subgraph_create_handler() {
+    init();
+    clear_db().await;
+
+    let mut ehb = EventHandlerBag::new();
+    ehb.register_after_subgraph_create(vec!["Project".to_string()], anef);
+
+    let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
+
+    let p0 = client
+        .create_node(
+            "Project",
+            "id name description status",
+            &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -326,8 +350,8 @@ async fn test_after_node_read_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -337,7 +361,7 @@ async fn test_after_node_read_handler() {
     assert_eq!(p0.get("status").unwrap(), "PENDING");
 
     let projects = client
-        .read_node("Project", "id status", Some("1234"), None)
+        .read_node("Project", "id status", None, None)
         .await
         .unwrap();
 
@@ -359,8 +383,8 @@ async fn test_after_node_update_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -373,9 +397,48 @@ async fn test_after_node_update_handler() {
         .update_node(
             "Project",
             "__typename id name status",
-            Some("1234"),
             Some(&json!({"name": {"EQ": "MJOLNIR"}})),
             &json!({"status": "ACTIVE"}),
+            None,
+        )
+        .await
+        .unwrap();
+
+    assert!(pu.is_null());
+}
+
+#[cfg(feature = "cypher")]
+#[tokio::test]
+async fn test_after_node_subgraph_update_handler() {
+    init();
+    clear_db().await;
+
+    let mut ehb = EventHandlerBag::new();
+    ehb.register_after_node_subgraph_update(vec!["Project".to_string()], anef);
+
+    let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
+
+    let p0 = client
+        .create_node(
+            "Project",
+            "id name description status",
+            &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
+        )
+        .await
+        .unwrap();
+    assert!(p0.is_object());
+    assert_eq!(p0.get("name").unwrap(), "MJOLNIR");
+    assert_eq!(p0.get("description").unwrap(), "Advanced armor");
+    assert_eq!(p0.get("status").unwrap(), "PENDING");
+
+    let pu = client
+        .update_node(
+            "Project",
+            "__typename id name status",
+            Some(&json!({"name": {"EQ": "MJOLNIR"}})),
+            &json!({"status": "ACTIVE"}),
+            None,
         )
         .await
         .unwrap();
@@ -398,8 +461,8 @@ async fn test_after_node_delete_handler() {
         .create_node(
             "Project",
             "id name description status",
-            Some("1234"),
             &json!({"name": "MJOLNIR", "description": "Advanced armor", "status": "PENDING"}),
+            None,
         )
         .await
         .unwrap();
@@ -410,9 +473,9 @@ async fn test_after_node_delete_handler() {
     let pd = client
         .delete_node(
             "Project",
-            Some("1234"),
             Some(&json!({"name": {"EQ": "MJOLNIR"}})),
             None,
+            None,
         )
         .await
         .unwrap();
@@ -432,16 +495,11 @@ async fn test_before_rel_create_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -450,12 +508,12 @@ async fn test_before_rel_create_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -475,16 +533,11 @@ async fn test_before_rel_read_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -493,12 +546,12 @@ async fn test_before_rel_read_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -511,7 +564,7 @@ async fn test_before_rel_read_handler() {
     assert_eq!(r0.get("dst").unwrap().get("name").unwrap(), "Bug Zero");
 
     let rels = client
-        .read_rel("Project", "issues", "id since", Some("1234"), None)
+        .read_rel("Project", "issues", "id since", None, None)
         .await
         .unwrap();
 
@@ -530,16 +583,11 @@ async fn test_before_rel_update_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -548,12 +596,12 @@ async fn test_before_rel_update_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -570,9 +618,9 @@ async fn test_before_rel_update_handler() {
             "Project",
             "issues",
             "id since",
-            Some("1234"),
             Some(&json!({"since": {"EQ": "2000"}})),
             &json!({"since": "2010"}),
+            None,
         )
         .await
         .unwrap();
@@ -592,16 +640,11 @@ async fn test_before_rel_delete_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -610,12 +653,12 @@ async fn test_before_rel_delete_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -631,10 +674,10 @@ async fn test_before_rel_delete_handler() {
         .delete_rel(
             "Project",
             "issues",
-            Some("1234"),
             Some(&json!({"since": {"EQ": "2010"}})),
             None,
             None,
+            None,
         )
         .await
         .unwrap();
@@ -654,16 +697,11 @@ async fn test_after_rel_create_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -672,12 +710,12 @@ async fn test_after_rel_create_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -697,16 +735,11 @@ async fn test_after_rel_read_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -715,12 +748,12 @@ async fn test_after_rel_read_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}}]
             ),
+            None,
         )
         .await
         .unwrap();
@@ -733,7 +766,7 @@ async fn test_after_rel_read_handler() {
     assert_eq!(r0.get("dst").unwrap().get("name").unwrap(), "Bug Zero");
 
     let rels = client
-        .read_rel("Project", "issues", "id since", Some("1234"), None)
+        .read_rel("Project", "issues", "id since", None, None)
         .await
         .unwrap();
 
@@ -752,16 +785,11 @@ async fn test_after_rel_update_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -770,12 +798,12 @@ async fn test_after_rel_update_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
             }]),
+            None,
         )
         .await
         .unwrap();
@@ -792,9 +820,71 @@ async fn test_after_rel_update_handler() {
             "Project",
             "issues",
             "id since",
-            Some("1234"),
             Some(&json!({"since": {"EQ": "2000"}})),
             &json!({"since": "2010"}),
+            None,
+        )
+        .await
+        .unwrap();
+
+    assert!(ru.is_null());
+}
+
+#[cfg(feature = "cypher")]
+#[tokio::test]
+async fn test_after_rel_subgraph_update_handler() {
+    init();
+    clear_db().await;
+
+    let mut ehb = EventHandlerBag::new();
+    ehb.register_after_rel_subgraph_update(vec!["ProjectIssuesRel".to_string()], aref);
+
+    let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
+
+    client
+        .create_node(
+            "Project",
+            "id name",
+            &json!({"name": "Project Zero"}),
+            None,
+        )
+        .await
+        .unwrap();
+    client
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
+        .await
+        .unwrap();
+
+    let results = client
+        .create_rel(
+            "Project",
+            "issues",
+            "__typename id since src { id name } dst { ...on Bug { id name } }",
+            &json!({"name": {"EQ": "Project Zero"}}),
+            &json!([{
+                "since": "2000",
+                "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}
+            }]),
+            None,
+        )
+        .await
+        .unwrap();
+
+    assert!(results.is_array());
+    let r0 = &results[0];
+    assert!(r0.is_object());
+    assert_eq!(r0.get("since").unwrap(), "2000");
+    assert_eq!(r0.get("src").unwrap().get("name").unwrap(), "Project Zero");
+    assert_eq!(r0.get("dst").unwrap().get("name").unwrap(), "Bug Zero");
+
+    let ru = client
+        .update_rel(
+            "Project",
+            "issues",
+            "id since",
+            Some(&json!({"since": {"EQ": "2000"}})),
+            &json!({"since": "2010"}),
+            None,
         )
         .await
         .unwrap();
@@ -814,16 +904,11 @@ async fn test_after_rel_delete_handler() {
     let mut client = cypher_test_client_with_events("./tests/fixtures/minimal.yml", ehb).await;
 
     client
-        .create_node(
-            "Project",
-            "id name",
-            Some("1234"),
-            &json!({"name": "Project Zero"}),
-        )
+        .create_node("Project", "id name", &json!({"name": "Project Zero"}), None)
         .await
         .unwrap();
     client
-        .create_node("Bug", "id name", Some("1234"), &json!({"name": "Bug Zero"}))
+        .create_node("Bug", "id name", &json!({"name": "Bug Zero"}), None)
         .await
         .unwrap();
 
@@ -832,12 +917,12 @@ async fn test_after_rel_delete_handler() {
             "Project",
             "issues",
             "__typename id since src { id name } dst { ...on Bug { id name } }",
-            Some("1234"),
             &json!({"name": {"EQ": "Project Zero"}}),
             &json!([{
                 "since": "2000",
                 "dst": {"Bug": {"EXISTING": {"name": {"EQ": "Bug Zero"}}}}}]
             ),
+            None,
         )
         .await
         .unwrap();
@@ -853,10 +938,10 @@ async fn test_after_rel_delete_handler() {
         .delete_rel(
             "Project",
             "issues",
-            Some("1234"),
             Some(&json!({"since": {"EQ": "2010"}})),
             None,
             None,
+            None,
         )
         .await
         .unwrap();
